import {
  watch
} from "./chunk.2WO4NHJ2.js";

// libs/core/src/utils/decorators/style-expression-property.ts
import { unsafeCSS } from "lit";
import { property } from "lit/decorators.js";

// libs/core/src/utils/helpers/style-expression-parser.ts
var viewportBreakpoints = {
  "0": "0px",
  "2xs": "320px",
  xs: "425px",
  s: "768px",
  m: "1024px",
  l: "1280px",
  xl: "1440px",
  "2xl": "2560px",
  "3xl": "3840px",
  "4xl": "4320px",
  "5xl": "6016px",
  "6xl": "7680px"
};
var breakpointValueRegex = /^([<|>]=?)?([0-9a-z]+)/;
var singleCharTokens = ["{", "}", ";", ","];
var whitespace = [" ", "/n"];
function tokenize(source) {
  const lexemes = [];
  let scanned = "";
  for (let i = 0; i < source.length; i++) {
    const c = source[i];
    if (!whitespace.includes(c))
      scanned += c;
    if (singleCharTokens.includes(c)) {
      lexemes.push(scanned.slice(0, -1));
      lexemes.push(c);
      scanned = "";
      continue;
    }
    if (whitespace.includes(c) || i === source.length - 1) {
      lexemes.push(scanned);
      scanned = "";
      continue;
    }
  }
  return lexemes.filter((l) => l !== "");
}
function parse(tokens) {
  const tree = [];
  let level = "bp";
  let scope = void 0;
  let expectMultiCondition = false;
  for (const t of tokens) {
    if (!singleCharTokens.includes(t)) {
      if (level === "val" && scope) {
        t !== "}" && scope.values.push(t);
      } else {
        if (scope && expectMultiCondition) {
          scope.breakpoint += `,${t}`;
          expectMultiCondition = false;
          continue;
        }
        if (!scope) {
          scope = { breakpoint: t, values: [] };
          tree.push(scope);
        } else {
          level = "val";
          scope.values.push(scope.breakpoint);
          scope.values.push(t);
          scope.breakpoint = "-";
        }
      }
      continue;
    }
    if (t === ",") {
      expectMultiCondition = true;
      continue;
    }
    if (t === "{") {
      level = "val";
      continue;
    }
    if (t === "}" || t === ";") {
      level = "bp";
      scope = void 0;
      continue;
    }
  }
  return tree.map((bp) => {
    if (bp.values.length === 0) {
      bp.values.push(bp.breakpoint);
      bp.breakpoint = "-";
    }
    return bp;
  });
}
function parseBreakpoint(bp) {
  const bps = bp.split(",");
  return bps.map((b) => {
    const match = b.trim().match(breakpointValueRegex);
    if (!match) {
      throw new Error(`Invalid breakpoint specifier: ${b}`);
    }
    return { condition: match[1], value: match[2] };
  });
}
function toCss(selector, property2, tree, valueTemplate = (v) => v, styleTemplate = (p, vs) => `${p}: ${vs.join(" ")};`) {
  let css = "";
  for (const bp of tree) {
    const bpSpecs = bp.breakpoint === "-" ? [{ condition: ">=", value: "0" }] : parseBreakpoint(bp.breakpoint);
    const query = bpSpecs.map(
      (b) => {
        var _a, _b;
        return `(${((_a = b.condition) == null ? void 0 : _a.includes("<")) ? "max-width" : "min-width"}: ${(_b = viewportBreakpoints[b.value]) != null ? _b : b.value})`;
      }
    ).join(" and ");
    const mq = `@media ${query} {${selector}{${styleTemplate(property2, bp.values.map(valueTemplate))}}}`;
    css += mq;
  }
  return css;
}

// libs/core/src/utils/decorators/style-expression-property.ts
function styleExpressionProperty(options) {
  return (proto, descriptor) => {
    var _a, _b, _c;
    const sel = (_a = options == null ? void 0 : options.selector) != null ? _a : String(":host");
    const prop = (_b = options == null ? void 0 : options.property) != null ? _b : String(descriptor);
    const valueTemplate = (_c = options == null ? void 0 : options.valueTemplate) != null ? _c : (v) => `var(--gds-space-${v})`;
    const styleTemplate = options == null ? void 0 : options.styleTemplate;
    property({ attribute: options == null ? void 0 : options.attribute })(proto, descriptor);
    watch(descriptor)(proto, descriptor, {
      value: function(oldValue, newValue) {
        const ast = parse(tokenize(newValue));
        const css = toCss(sel, prop, ast, valueTemplate, styleTemplate);
        this[`__${String(descriptor)}_ast`] = ast;
        this._dynamicStylesController.inject(
          `sep_${String(descriptor)}`,
          unsafeCSS(css)
        );
      }
    });
  };
}

export {
  styleExpressionProperty
};
