import { GdsElement } from '../../../gds-element';
/**
 * `gds-text` is a custom element that provides a flexible text system.
 * For accessibility reasons, it is recommended to use the `gds-text` element to display text content with flexibility like changing the tag, wrap the text and max length in characters.
 *
 * @element gds-text
 * @status beta
 *
 */
export declare class GdsText extends GdsElement {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Controls the tag of the text.
     * Supports all valid HTML tags like h1, h2, h3, h4, h5, h6, p, span, etc.
     *
     * @property tag
     */
    tag: string;
    /**
     * Controls the size of the text.
     * Supports all typography size tokens from the design system.
     *
     * You can apply size like this:
     * ```html
     * <gds-text size="body-m"></gds-text>
     * ```
     *
     * These are the available values you can use to define size:
     *
     * `heading-xl`,
     * `heading-l`,
     * `heading-m`,
     * `heading-s`,
     * `heading-xs`,
     * `heading-2xs`,
     * `detail-m`,
     * `detail-s`,
     * `detail-xs`,
     * `body-l`,
     * `body-m`,
     * `body-s`,
     * `display-2xl`,
     * `display-xl`,
     * `display-l`,
     * `display-m`,
     * `display-s `,
     * `preamble-2xl`,
     * `preamble-xl`,
     * `preamble-l`,
     * `preamble-m`,
     * `preamble-s`,
     * `preamble-xs`,
     *
     * @property size
     */
    size?: string;
    /**
     * Controls the `font-weight` of the text.
     * Supports all the weigh tokens.
     *
     * @property weight
     */
    weight?: string;
    /**
     * Controls the margin of the text.
     * Supports all the default margin values.
     *
     * @property margin
     */
    margin?: string;
    /**
     * Controls the text-wrap property of the text.
     * Supports all valid CSS text-wrap values.
     *
     * @property wrap
     */
    wrap?: string;
    /**
     * Controls the text-transform property of the text.
     * Supports all valid CSS text-transform values.
     *
     * @property transform
     */
    transform?: string;
    /**
     * Controls the max length of the text in characters.
     * Length is by defualt in characters to keep conistency with the text content.
     *
     * You can apply length like this:
     *
     * ```html
     * <gds-text length="50"></gds-text>
     * ```
     *
     * @property length
     */
    length?: string;
    /**
     * Controls the max-width property of the text.
     * Supports all valid CSS max-width values.
     *
     * @property max
     */
    min?: string;
    /**
     * Controls the text-align property of the text.
     * Supports all valid CSS text-align values.
     *
     * @property align
     */
    align?: string;
    /**
     * Controls the number of lines it should show.
     *
     * @property lines
     */
    lines?: number;
    /**
     * Controls the color property of the text.
     * Supports all the color tokens from the design system.
     *
     * @property color
     *
     * @example
     * ```html
     * <gds-text color="primary"></gds-text>
     * ```
     */
    color?: string;
    render(): import("lit").TemplateResult;
}
