import { GdsElement } from '../../gds-element';
import { GdsSegment } from '../../components/segmented-control/segment';
import '../icon/icons/chevron-left';
import '../icon/icons/chevron-right';
/**
 * @element gds-segmented-control
 * A segmented control is a group of 2-5 buttons that lets the user switch views or sort elements.
 *
 * @status beta
 *
 * @slot - Segments to display in the control
 *
 * @event changed - Fires when the selected segment is changed
 */
export declare class GdsSegmentedControl<ValueT = any> extends GdsElement {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Minimum width of each segment. Used for calculating the number of visible
     * segments that can fit based on the available space.
     * @attr seg-min-width
     */
    segMinWidth: number;
    /**
     * Size of the segmented control
     * @attr size
     */
    size: 'small' | 'medium';
    /**
     * The value of the currently selected segment. Setting this property will
     * select the segment with the matching value.
     * @attr value
     */
    get value(): ValueT | undefined;
    set value(val: ValueT | undefined);
    /**
     * Returns the segments in the control
     * @readonly
     */
    get segments(): GdsSegment<any>[];
    private _elSlot;
    private _elIndicator;
    private _elTrack;
    private _elSegments;
    private _showPrevButton;
    private _showNextButton;
    connectedCallback(): void;
    render(): any;
    private _recalculateMinWidth;
}
